@@ -23,6 +23,7 @@ sub init {
     $self->register_suffix(".c");
     $self->register_suffix(".cpp");
     $self->register_suffix(".cc");
+    $self->register_suffix(".CC");
     $self->register_suffix(".C");
     $self->register_suffix(".h");
     $self->register_suffix(".H");
@@ -70,15 +71,15 @@ __END__
 
 =head1 NAME
 
-File::Comments::Plugins::C - Plugin to detect comments in C/C++ source code
+File::Comments::Plugin::C - Plugin to detect comments in C/C++ source code
 
 =head1 SYNOPSIS
 
-    use File::Comments::Plugins::C;
+    use File::Comments::Plugin::C;
 
 =head1 DESCRIPTION
 
-File::Comments::Plugins::C is a plugin for the File::Comments framework.
+File::Comments::Plugin::C is a plugin for the File::Comments framework.
 
 Both /* ... */ and // style comments are recognized.
 
